//----------------------------------------------------------------------------
// WirelessUSBサンプルプログラム
// P1[7]をプルアップにして、GNDとの間にスイッチを付ける
// 50msごとにデータ送信する
// 送信データは8バイト長で先頭がスイッチ情報
// 　+0    ：スイッチ情報（ONなら'1'、OFFなら'0'）
// 　+1～+6：コールサイン（6文字)
// 　+7　　：EOS(0x00）
//----------------------------------------------------------------------------

#include <m8c.h>
#include "PSoCAPI.h"
#include "psocgpioint.h"

#define WUSB_CHANNEL	30
const BYTE pn_code_table[] =
{
	0x36, 0xF3, 0x8C, 0xB5, 0x11, 0x4A, 0xCA, 0x1F
};

#pragma interrupt_handler isr_timer8
#define	TXBUFSIZE	8
const unsigned char msg[TXBUFSIZE] = {'0', 'J', 'A', '1', 'Y', 'R', 'L', 0x00}; // <= 各自のコールサインを入れる
unsigned char	txdat[TXBUFSIZE];
unsigned char	tint;	// タイマ割り込み発生フラグ

void isr_timer8(void)
{
	tint = 1;
}

void main()
{
	unsigned char c;
	for (c=1; c<TXBUFSIZE; c++)	// 送信データ初期化
		txdat[c] = msg[c];
	tint = 0;			// 割り込みフラグクリア
	WirelessUSBLS_1_Start();	//ワイヤレスUSBの初期化
	WirelessUSBLS_1_SetChannel(WUSB_CHANNEL);
	WirelessUSBLS_1_SetPnCode(pn_code_table);
	M8C_EnableGInt;			// CPU割り込み許可
	Timer8_1_EnableInt();		// タイマ割り込み許可（50ms周期）
	Timer8_1_Start();		// タイマスタート
	while(1) {
		if (tint != 0) {	// タイマ割り込みが発生したらデータ送信
			tint = 0;
			SW_Data_ADDR |= SW_MASK;
			if (SW_Data_ADDR & SW_MASK)
				txdat[0] = '0';
			else	txdat[0] = '1';
			WirelessUSBLS_1_SendData(TXBUFSIZE, txdat);
		}
	}
}
